<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Järjestelmänvalvojan oikeudet vaaditaan</translation>
    </message>
    <message>
        <location filename="../cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Toiminto vaatii järjestelmänvalvojan oikeudet. Käynnistä sovellus uudelleen ja anna salasanasi pyydettäessä.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live-asennusmedia havaittu. Valitse järjestelmän root juuriosio
(Linux yhteensopivat osiot näytetään)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Käytä yksinkertaistettua valikkorakennetta ilman jatkevalikkoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Käytä yleisvalikkoja (ei jatkevalikkoja)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Käynnistä tähän</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Aseta muotoon &apos;0&apos; käynnistääksesi välittömästi ilman valikkonäyttöä, tai  &apos;-1&apos; odottaaksesi loputtomasti </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Valikon aikavalinta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Kernel parametrit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekuntia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Tämä valinta päällekytkettynä valitsit sitten minkä tahansa grub-valikko-valinnan hyvänsä, se tulee olemaan uusi vakio tulevaisuuden käynnistyksissä </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Kytke viimeisimmän käynnistyksen valinnan tallennus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Hallitse UEFI Boot asetuksia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Taustakuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Ota teema käyttöön</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Käynnistyskuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Viestit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Erittäin tarkka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Tarkka (oletus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Rajoitettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Näytä loki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Edelleen käynnissä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <location filename="../mainwindow.cpp" line="1346"/>
        <location filename="../mainwindow.cpp" line="1359"/>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Käynnistysanimaatiota asennetaan, odota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Updating sources</source>
        <translation>Päivitetään lähteitä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Could not install the bootsplash.</source>
        <translation>Käynnistyksen splash-kuvaa ei voitu asentaa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Could not create a temporary folder</source>
        <translation>Ei voitu luoda väliaikaista kansiota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Cannot continue</source>
        <translation>Ei voida jatkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Ei voi avata LUKS. Poistutaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Chroot-ympäristöä ei voitu luoda, käynnistysvaihtoehtoja ei voitu muuttaa. Poistutaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="887"/>
        <location filename="../mainwindow.cpp" line="1266"/>
        <source>Updating configuration, please wait</source>
        <translation>Asetuksia päivitetään, odota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="958"/>
        <source>Updating initramfs...</source>
        <translation>Päivitetään initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="972"/>
        <location filename="../mainwindow.cpp" line="1281"/>
        <source>Updating grub...</source>
        <translation>Päivitetään grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="998"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1000"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ohjelma yleisille aloitusvalinnoille</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1002"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>%1 License</source>
        <translation>%1 lisenssi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <location filename="../mainwindow.cpp" line="1243"/>
        <source>Running in a Virtual Machine</source>
        <translation>Ajettuna virtuaalikoneessa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <location filename="../mainwindow.cpp" line="1244"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Järjestelmäsi on ajossa virtuaalikoneessa,
Käynnistyksen Plymouth-animaatio toimii täten rajatulla tavalla, et myöskään voi esikatsella teemaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-paketteja ei asennettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-paketteja ei ole tällä hetkellä asennettuna.
Voidaanko jatkaa ja asentaa ne?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Kuvat (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Log not found</source>
        <translation>Lokitiedostoa ei löytynyt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Could not find log at </source>
        <translation>Lokitietoja ei löydetty kohteessa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1346"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Ei voi hakea UUID:tä kohteelle %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1354"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Syötä salasana avataksesi %1 salauksella varustetun osion:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>Salasana peruttu tai tyhjä kohteelle %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Ei voi avata %1 LUKS-säilöstä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Prosessi on yhä käynnissä. Haluatko varmasti lopettaa?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>Live System Detected</source>
        <translation>Live-tila tunnistettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Käytät tällä hetkellä live-tilaa. Haluatko muokata käynnissä olevan järjestelmän tai asennetun tietokoneen käynnistysasetuksia?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Live System</source>
        <translation>Live-tila</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Installed System</source>
        <translation>Asennettu tietokone</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Failed to update package sources.</source>
        <translation>Pakettilähteiden päivitys epäonnistui.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Installing packages:</source>
        <translation>Asennetaan paketteja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Success</source>
        <translation>Onnistui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash asennettu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to create temporary file.</source>
        <translation>Väliaikaisen tiedoston luominen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Käytät tällä hetkellä live-tilan toram-asetusta. Muista tallentaa pysyvä tiedosto tai remaster, muuten tehdyt muutokset menetetään.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Muutokset on otettu käyttöön.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>Operation Complete</source>
        <translation>Tehtävä valmis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Select image to display in bootloader</source>
        <translation>Valitse käynnistyslataajassa näytettävä kuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1192"/>
        <source>Boot Log</source>
        <translation>Boot-loki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1232"/>
        <source>Needs reboot</source>
        <translation>Käynnistä uudelleen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth asennettiin juuri, järjestelmä on luultavasti käynnistettävä uudelleen ennen katselua</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Click to select theme</source>
        <translation>Klikkaa valitaksesi teema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Select GRUB theme</source>
        <translation>Valitse GRUB:in teema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ohjelma yleisille aloitusvalinnoille</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
</context>
</TS>